NAME

Photonic::WEM::S::Metric

VERSION

version 0.025

COPYRIGHT NOTICE

Photonic - A perl package for calculations on photonics and metamaterials.

Copyright (C) 2016 by W. Luis Mochán

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 1, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301 USA

mochan@fis.unam.mx

Instituto de Ciencias Físicas, UNAM
Apartado Postal 48-3
62251 Cuernavaca, Morelos
México

SYNOPSIS

use Photonic::WEM::S::Metric;
my $gGG=Photonic::WEM::S::Metric->new(
        mu => $mu,
        geometry=>$geometry, epsilon=>$eps,
        wavenumber => $q, $wavevector=>k);
f($gGG->value);

DESCRIPTION

Calculates the retarded metric tensor g_{GG'}^{ij} for use in the calculation of the retarded Haydock coefficients for the wave equation in a medium of arbitrary composition where the reference has no dissipation.

Implements 'Photonic::Roles::Metric'. Look there for the basic attributes and methods.

OTHER ATTRIBUTES

  • mu

    Real space complex magnetic permeability for each volume element.

METHODS

  • new(mu=>$mu, geometry=>$g, epsilon=>$e, $wavenumber=>$q, $wavevector=>$k);

    Create a new Ph::WEM::S::Metric object with permeability $mu, Geometry $g, dielectric function of the host $e, vacuum wavenumber $q=omega/c and wavevector $k. $q and $k are real.

  • apply($psi)

    Create and apply the magnetic metric to the state $psi provided in Haydock when it calls this method.